Templating - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Templating

Templating is the task of building HTML pages by taking an HTML template and to fill it with information unique a page.

Betty uses Jinja2 to parse `*.j2` templates. This allows your HTML or other code to receive data from your ancestry, read configuration, any much more.

## Adding or overriding templates

Any template file can be overridden by adding a file with the same name to the same subdirectory within your extension or project’s assets directory.

## In this section

- Globals

- Filters

- Tests